| Title: | Early Warning Information on Landslides in Sri Lanka During the Ditwah Storm |
|---|---|
| Description: | Provides curated early warning data on landslides in Sri Lanka during the Ditwah storm. It includes structured, machine-readable tidy dataset. This is developed for education and research purposes. |
| Authors: | Thiyanga S. Talagala [aut, cre] (ORCID: <https://orcid.org/0000-0002-0656-9789>), Geethma R. Jayasinghe [aut], Y. M. Amali P. Rajapaksha [aut], N. G. Shehara Minimuthu [aut], Y. G. D. M. Savindya Thathsarani [aut] |
| Maintainer: | Thiyanga S. Talagala <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.2.0 |
| Built: | 2026-05-27 07:06:27 UTC |
| Source: | https://github.com/cran/ditwahLandslide |
A dataset containing early warning messages for landslide-prone areas, including report details, validity periods, locations, and warning levels.
ditwah_landslides_warningsditwah_landslides_warnings
A data frame with the following variables:
chr. Identifier of the data analyst
dttm. Date on which the landslide early warning report was issued.
chr. Time at which the report was issued, in HH:MM format.
chr. Unique identifier for each warning message. Encodes the warning type, date, time, and message sequence.
dttm. Start date from which the warning is valid.
chr. Start time from which the warning is valid, in HH:MM format.
dttm. End date until which the warning remains valid.
chr. End time until which the warning remains valid, in HH:MM format.
chr. Administrative district where the potential landslide risk has been identified.
chr. Specific locality, town, or area within the district affected by the warning.
dbl. Landslide early warning level (1 = Level 1, 2 = Level 2, 3 = Level 3). Represents the severity of the situation.
dbl. Direction and magnitude of the landslide (1-shifted one level up, 2-shifted two levels up, -1-shifted one level down, -2-shifted two levels down).
Province
Based on land slides early warning pdf reports published by Disaster Management Centre, Sri Lanka. The data from PDF files were cleaned and processes by the package authors. Accessed from https://www.dmc.gov.lk/index.php?option=com_dmcreports&view=reports&Itemid=276&report_type_id=5&lang=en
This function launches the Shiny application included in the
ditwahLandslide package. The app must be located in
inst/app/ within the package source. When installed, this
directory is available via system.file().
run_app(...)run_app(...)
... |
Additional arguments passed to |
The Shiny app is launched; no R object is returned.
if (interactive()) { run_app() }if (interactive()) { run_app() }
Temporal progression of landslide warning state
viz_landslide_warnings_from_to( data, district = NULL, province = NULL, interactivity = TRUE, ang = 90 )viz_landslide_warnings_from_to( data, district = NULL, province = NULL, interactivity = TRUE, ang = 90 )
data |
name of the dataset, by default ditwah_landslides_warnings |
district |
District name or All, if no district put NULL |
province |
Province name or All, if no province put NULL |
interactivity |
if TRUE interactive plot will be generated, if FALSE static plot will be generated |
ang |
angle of the x-axis lables |
Heatmap plot of landslide warnings
Thiyanga S. Talagala, Geethma R. Jayasinghe, Y. M. Amali P. Rajapaksha